StateBridgeClient

Struct StateBridgeClient 

pub struct StateBridgeClient {
    pub(crate) client: Client,
}
Client for interacting with the key-management state bridge. This is used to read and write state held by the clients

Fields

client: Client

Implementations

Source

impl StateBridgeClient

pub fn is_bridge_registered(&self) -> bool

Returns true if a state bridge implementation has been registered.

pub fn register_bridge( &self, bridge_impl: Box<dyn StateBridgeImpl + Send + Sync>, )

Registers a bridge implementation used to read and write temporary key-management state.

Source

impl StateBridgeClient

pub fn register_bridge_impl(&self, bridge_impl: Arc<dyn StateBridgeForeignImpl>)

Registers the host-supplied state bridge implementation.

Source

impl StateBridgeClient

pub async fn set_user_key(&self, value: &SymmetricCryptoKey)

Sets the user_key value in client-managed state.

pub async fn get_user_key(&self) -> Option<SymmetricCryptoKey>

Gets the user_key value from client-managed state, if available.

pub async fn clear_user_key(&self)

Clears the user_key value from client-managed state.

pub async fn set_user_key_id(&self, value: &KeyId)

Sets the user_key_id value in client-managed state.

pub async fn get_user_key_id(&self) -> Option<KeyId>

Gets the user_key_id value from client-managed state, if available.

pub async fn clear_user_key_id(&self)

Clears the user_key_id value from client-managed state.

pub async fn set_persistent_pin_envelope( &self, value: &PasswordProtectedKeyEnvelope, )

Sets the persistent_pin_envelope value in client-managed state.

pub async fn get_persistent_pin_envelope( &self, ) -> Option<PasswordProtectedKeyEnvelope>

Gets the persistent_pin_envelope value from client-managed state, if available.

pub async fn clear_persistent_pin_envelope(&self)

Clears the persistent_pin_envelope value from client-managed state.

pub async fn set_ephemeral_pin_envelope( &self, value: &PasswordProtectedKeyEnvelope, )

Sets the ephemeral_pin_envelope value in client-managed state.

pub async fn get_ephemeral_pin_envelope( &self, ) -> Option<PasswordProtectedKeyEnvelope>

Gets the ephemeral_pin_envelope value from client-managed state, if available.

pub async fn clear_ephemeral_pin_envelope(&self)

Clears the ephemeral_pin_envelope value from client-managed state.

pub async fn set_encrypted_pin(&self, value: &EncString)

Sets the encrypted_pin value in client-managed state.

pub async fn get_encrypted_pin(&self) -> Option<EncString>

Gets the encrypted_pin value from client-managed state, if available.

pub async fn clear_encrypted_pin(&self)

Clears the encrypted_pin value from client-managed state.

pub async fn set_v2_upgrade_token(&self, value: &V2UpgradeToken)

Sets the v2_upgrade_token value in client-managed state.

pub async fn get_v2_upgrade_token(&self) -> Option<V2UpgradeToken>

Gets the v2_upgrade_token value from client-managed state, if available.

pub async fn clear_v2_upgrade_token(&self)

Clears the v2_upgrade_token value from client-managed state.

pub async fn set_account_cryptographic_state( &self, value: &WrappedAccountCryptographicState, )

Sets the account_cryptographic_state value in client-managed state.

pub async fn get_account_cryptographic_state( &self, ) -> Option<WrappedAccountCryptographicState>

Gets the account_cryptographic_state value from client-managed state, if available.

pub async fn clear_account_cryptographic_state(&self)

Clears the account_cryptographic_state value from client-managed state.

pub async fn set_masterpassword_unlock_data( &self, value: &MasterPasswordUnlockData, )

Sets the masterpassword_unlock_data value in client-managed state.

pub async fn get_masterpassword_unlock_data( &self, ) -> Option<MasterPasswordUnlockData>

Gets the masterpassword_unlock_data value from client-managed state, if available.

pub async fn clear_masterpassword_unlock_data(&self)

Clears the masterpassword_unlock_data value from client-managed state.

pub async fn set_webauthn_prf_unlock_data(&self, value: &WebAuthnPrfUnlockData)

Sets the webauthn_prf_unlock_data value in client-managed state.

pub async fn get_webauthn_prf_unlock_data( &self, ) -> Option<WebAuthnPrfUnlockData>

Gets the webauthn_prf_unlock_data value from client-managed state, if available.

pub async fn clear_webauthn_prf_unlock_data(&self)

Clears the webauthn_prf_unlock_data value from client-managed state.

pub async fn set_kdf_config(&self, value: &Kdf)

Sets the kdf_config value in client-managed state.

pub async fn get_kdf_config(&self) -> Option<Kdf>

Gets the kdf_config value from client-managed state, if available.

pub async fn clear_kdf_config(&self)

Clears the kdf_config value from client-managed state.

pub async fn set_v2_encrypted_migrations_grace_period_start( &self, value: &V2EncryptedMigrationsGracePeriodStart, )

Sets the v2_encrypted_migrations_grace_period_start value in client-managed state.

pub async fn get_v2_encrypted_migrations_grace_period_start( &self, ) -> Option<V2EncryptedMigrationsGracePeriodStart>

Gets the v2_encrypted_migrations_grace_period_start value from client-managed state, if available.

pub async fn clear_v2_encrypted_migrations_grace_period_start(&self)

Clears the v2_encrypted_migrations_grace_period_start value from client-managed state.