pub struct StateBridgeClient {
pub(crate) client: Client,
}Expand description
Client for interacting with the key-management state bridge. This is used to read and write state held by the clients
Fields
client: ClientImplementations
Sourceimpl StateBridgeClient
impl StateBridgeClient
Sourcepub fn is_bridge_registered(&self) -> bool
pub fn is_bridge_registered(&self) -> bool
Returns true if a state bridge implementation has been registered.
Sourcepub fn register_bridge(
&self,
bridge_impl: Box<dyn StateBridgeImpl + Send + Sync>,
)
pub fn register_bridge( &self, bridge_impl: Box<dyn StateBridgeImpl + Send + Sync>, )
Registers a bridge implementation used to read and write temporary key-management state.
Sourceimpl StateBridgeClient
impl StateBridgeClient
Sourcepub async fn set_user_key(&self, value: &SymmetricCryptoKey)
pub async fn set_user_key(&self, value: &SymmetricCryptoKey)
Sets the user_key value in client-managed state.
Sourcepub async fn get_user_key(&self) -> Option<SymmetricCryptoKey>
pub async fn get_user_key(&self) -> Option<SymmetricCryptoKey>
Gets the user_key value from client-managed state, if available.
Sourcepub async fn clear_user_key(&self)
pub async fn clear_user_key(&self)
Clears the user_key value from client-managed state.
Sourcepub async fn set_persistent_pin_envelope(
&self,
value: &PasswordProtectedKeyEnvelope,
)
pub async fn set_persistent_pin_envelope( &self, value: &PasswordProtectedKeyEnvelope, )
Sets the persistent_pin_envelope value in client-managed state.
Sourcepub async fn get_persistent_pin_envelope(
&self,
) -> Option<PasswordProtectedKeyEnvelope>
pub async fn get_persistent_pin_envelope( &self, ) -> Option<PasswordProtectedKeyEnvelope>
Gets the persistent_pin_envelope value from client-managed state, if available.
Sourcepub async fn clear_persistent_pin_envelope(&self)
pub async fn clear_persistent_pin_envelope(&self)
Clears the persistent_pin_envelope value from client-managed state.
Sourcepub async fn set_ephemeral_pin_envelope(
&self,
value: &PasswordProtectedKeyEnvelope,
)
pub async fn set_ephemeral_pin_envelope( &self, value: &PasswordProtectedKeyEnvelope, )
Sets the ephemeral_pin_envelope value in client-managed state.
Sourcepub async fn get_ephemeral_pin_envelope(
&self,
) -> Option<PasswordProtectedKeyEnvelope>
pub async fn get_ephemeral_pin_envelope( &self, ) -> Option<PasswordProtectedKeyEnvelope>
Gets the ephemeral_pin_envelope value from client-managed state, if available.
Sourcepub async fn clear_ephemeral_pin_envelope(&self)
pub async fn clear_ephemeral_pin_envelope(&self)
Clears the ephemeral_pin_envelope value from client-managed state.
Sourcepub async fn set_encrypted_pin(&self, value: &EncString)
pub async fn set_encrypted_pin(&self, value: &EncString)
Sets the encrypted_pin value in client-managed state.
Sourcepub async fn get_encrypted_pin(&self) -> Option<EncString>
pub async fn get_encrypted_pin(&self) -> Option<EncString>
Gets the encrypted_pin value from client-managed state, if available.
Sourcepub async fn clear_encrypted_pin(&self)
pub async fn clear_encrypted_pin(&self)
Clears the encrypted_pin value from client-managed state.
Sourcepub async fn set_v2_upgrade_token(&self, value: &V2UpgradeToken)
pub async fn set_v2_upgrade_token(&self, value: &V2UpgradeToken)
Sets the v2_upgrade_token value in client-managed state.
Sourcepub async fn get_v2_upgrade_token(&self) -> Option<V2UpgradeToken>
pub async fn get_v2_upgrade_token(&self) -> Option<V2UpgradeToken>
Gets the v2_upgrade_token value from client-managed state, if available.
Sourcepub async fn clear_v2_upgrade_token(&self)
pub async fn clear_v2_upgrade_token(&self)
Clears the v2_upgrade_token value from client-managed state.
Sourcepub async fn set_account_cryptographic_state(
&self,
value: &WrappedAccountCryptographicState,
)
pub async fn set_account_cryptographic_state( &self, value: &WrappedAccountCryptographicState, )
Sets the account_cryptographic_state value in client-managed state.
Sourcepub async fn get_account_cryptographic_state(
&self,
) -> Option<WrappedAccountCryptographicState>
pub async fn get_account_cryptographic_state( &self, ) -> Option<WrappedAccountCryptographicState>
Gets the account_cryptographic_state value from client-managed state, if available.
Sourcepub async fn clear_account_cryptographic_state(&self)
pub async fn clear_account_cryptographic_state(&self)
Clears the account_cryptographic_state value from client-managed state.
Sourcepub async fn set_masterpassword_unlock_data(
&self,
value: &MasterPasswordUnlockData,
)
pub async fn set_masterpassword_unlock_data( &self, value: &MasterPasswordUnlockData, )
Sets the masterpassword_unlock_data value in client-managed state.
Sourcepub async fn get_masterpassword_unlock_data(
&self,
) -> Option<MasterPasswordUnlockData>
pub async fn get_masterpassword_unlock_data( &self, ) -> Option<MasterPasswordUnlockData>
Gets the masterpassword_unlock_data value from client-managed state, if available.
Sourcepub async fn clear_masterpassword_unlock_data(&self)
pub async fn clear_masterpassword_unlock_data(&self)
Clears the masterpassword_unlock_data value from client-managed state.